@@ -3,14 +3,15 @@
 #' @examples
 #'
 #' ## Serial axes (radial and parallel coordinate) examples
-#'
-#' s <- l_serialaxes(data=oliveAcids, color=olive$Area, title="olive data")
-#' sGrob_radial <- loonGrob(s)
-#' library(grid)
-#' grid.newpage(); grid.draw(sGrob_radial)
-#' s['axesLayout'] <- 'parallel'
-#' sGrob_parallel <- loonGrob(s)
-#' grid.newpage(); grid.draw(sGrob_parallel)
+#' if(interactive()) {
+#'   s <- l_serialaxes(data=oliveAcids, color=olive$Area, title="olive data")
+#'   sGrob_radial <- loonGrob(s)
+#'   library(grid)
+#'   grid.newpage(); grid.draw(sGrob_radial)
+#'   s['axesLayout'] <- 'parallel'
+#'   sGrob_parallel <- loonGrob(s)
+#'   grid.newpage(); grid.draw(sGrob_parallel)
+#' }
 #'
 #' @export
 
@@ -416,7 +417,13 @@ get_scaledData <- function(data,
     if(missing(data) || is.null(data) || is.null(displayOrder)) return(NULL)
 
     if(!is.null(sequence)) {
-        col_name <- colnames(data)
+
+        col_name <- make.names(colnames(data))
+        # sequence names may involve invalid chars
+        # such as `(`, `)`, ` ` space, etc.
+        # call function `make.names` can remove all these chars to match data column names
+        sequence <- make.names(sequence)
+
         if(!all(sequence %in% col_name)) {
             warning("unknown variable names in sequence")
             sequence <- intersect(sequence, col_name)
