@@ -3,7 +3,7 @@
 namespace eval loon::listfns {
 
     namespace export interleave
-    
+
     proc isNumeric {vec} {
 	foreach x $vec {
 	    if {![string is double $x]} {
@@ -31,17 +31,17 @@ namespace eval loon::listfns {
 	return 1
     }
 
-    
+
     proc isPositiveNumber {vec} {
 	foreach x $vec {
 	    if {![string is double $x] || $x < 0} {
 		return 0
 	    }
 	}
-	return 1	
+	return 1
     }
 
-    
+
     proc isBoolean {vec} {
 	foreach x $vec {
 	    if {![string is boolean $x]} {
@@ -59,7 +59,7 @@ namespace eval loon::listfns {
 	}
 	return 1
     }
-    
+
     proc isColor {vec} {
 	foreach x $vec {
 	    if {[catch {winfo rgb . $x}]} {
@@ -68,7 +68,7 @@ namespace eval loon::listfns {
 	}
 	return 1
     }
-    
+
     proc toHexcolor {vec} {
 	set hexcolor {}
 	if {[llength $vec] eq 1} {
@@ -80,23 +80,23 @@ namespace eval loon::listfns {
 	}
 	return $hexcolor
     }
-    
+
     proc toNumeric {vec} {
 	set out {}
 	set val -1
-	
+
 	foreach x $vec {
 	    if {![info exists arr($x)]} {
 		set arr($x) [incr val]
 	    }
 	    lappend out $arr($x)
 	}
-	return $out	
+	return $out
     }
-    
+
     ## lsort -unique is still faster
     proc unique {vec} {
-        
+
         set d [dict create]
 
         foreach x $vec {
@@ -104,10 +104,10 @@ namespace eval loon::listfns {
                 dict set d $x TRUE
             }
         }
-        
+
         return [dict keys $d]
-    } 
-    
+    }
+
 
     ## map input to colors
     proc mapColor {vec} {
@@ -121,7 +121,7 @@ namespace eval loon::listfns {
 
 	    ## Use available colors
 	    set nColors [llength $::loon::Options(colors)]
-	    
+
 	    if {$nGroups > $nColors} {
 		if {$::loon::Options(colors-palette) ne "hcl"} {
 		    puts "warning: need more colors than are\
@@ -133,18 +133,18 @@ namespace eval loon::listfns {
 	    } else {
 		set colors [lrange $::loon::Options(colors) 0 [expr {$nColors-1}]]
 	    }
-	    
+
 	}
-	
+
 	foreach group $groups col $colors {
 	    set table($group) $col
 	}
-	
+
 	set col {}
 	foreach v $vec {
 	    lappend col $table($v)
 	}
-	
+
 	return $col
     }
 
@@ -162,7 +162,7 @@ namespace eval loon::listfns {
 
 	set step [expr {($to - $from)/($n-1.0)}]
 	set out $from
-	set nm1 [expr {$n - 1}]	
+	set nm1 [expr {$n - 1}]
 	for {set i 1} {$i < $nm1} {incr i} {
 	    lappend out [expr {$from + $i*$step}]
 	}
@@ -179,22 +179,22 @@ namespace eval loon::listfns {
 	    if {$element} {
 		lappend which $i
 	    }
-	    incr i	
-	} 
+	    incr i
+	}
 	return $which
     }
     proc subset {L which} {
 	set res {}
-	
+
 	foreach w $which {
 	    lappend res [lindex $L $w]
 	}
 	return $res
     }
-    
+
     proc subsetLogical {L which} {
 	set res {}
-	
+
 	foreach e $L w $which {
 	    if {$w} {
 		lappend res $e
@@ -216,7 +216,7 @@ namespace eval loon::listfns {
 		if {[lindex $vec $i]< $min} {set min [lindex $vec $i]}
 	    }
 	}
-	return $min	
+	return $min
     }
 
     proc max {vec {index "all"}} {
@@ -231,7 +231,7 @@ namespace eval loon::listfns {
 		if {[lindex $vec $i] > $max} {set max [lindex $vec $i]}
 	    }
 	}
-	return $max	
+	return $max
     }
 
 
@@ -239,16 +239,16 @@ namespace eval loon::listfns {
 	if {$index eq "all"} {
 	    set min [lindex $vec 0]
 	    set max $min
-	    
+
 	    foreach x $vec {
 		if {$x < $min} {set min $x}
 		if {$x > $max} {set max $x}
 	    }
-	    
+
 	} else {
 	    set min [lindex $vec [lindex $index 0]]
 	    set max $min
-	    
+
 	    foreach i $index {
 		set x [lindex $vec $i]
 		if {$x < $min} {set min $x}
@@ -259,30 +259,34 @@ namespace eval loon::listfns {
     }
 
     # http://wiki.tcl.tk/1354
-    proc sum L {expr [join $L +]+0} 
+    proc sum L {expr [join $L +]+0}
 
     proc scale01 {vec {min ""} {max ""}} {
-	
+
 	if {$min eq "" || $max eq ""} {
 	    set mm [MinMax $vec]
 	    set min [lindex $mm 0]
 	    set max [lindex $mm 1]
 	}
-	
+
 	set range [expr {$max - $min}]
-	
+
+	if {$range eq 0} {
+	   set range 1
+	}
+
 	set svec [list]
 	foreach x $vec {
 	    lappend svec [expr {($x - $min)/double($range)}]
 	}
-	
+
 	return $svec
     }
-    
-    
+
+
     proc scale {vec {mean ""} {stdev ""}} {
 	if {$mean eq ""} {
-	    set mean [mean $vec]	   
+	    set mean [mean $vec]
 	}
 	if {$stdev eq ""} {
 	    set stdev [stdev $vec $mean]
@@ -294,7 +298,7 @@ namespace eval loon::listfns {
 	}
 	return $out
     }
-    
+
     proc mean {vec} {
 	set n [llength $vec]
 	set sum 0
@@ -303,7 +307,7 @@ namespace eval loon::listfns {
 	}
 	return [expr {double($sum)/$n}]
     }
-    
+
     proc median {vec} {
        if {[set len [llength $vec]] % 2} then {
          return [lindex [lsort -real $vec] [expr {($len-1) / 2}]]
@@ -312,7 +316,7 @@ namespace eval loon::listfns {
                         + [lindex $sorted [expr {$len/2}]]) / 2.0}]
        }
     }
-    
+
     proc stdev {vec {mean ""}} {
 	set n [llength $vec]
 	if {$mean eq ""} {
@@ -324,7 +328,7 @@ namespace eval loon::listfns {
 	}
 	return [expr {sqrt(double($ssum)/($n - 1))}]
     }
-    
+
     # http://wiki.tcl.tk/12848
     proc lapply {list FUN} {
 	set res {}
@@ -333,21 +337,21 @@ namespace eval loon::listfns {
 	}
 	return $res
     }
-    
+
     proc all {list} {
 	foreach element $list {
 	    if {$element} {} else { return 0 }
-	} 
+	}
     	return 1
     }
-    
+
     proc any {list} {
 	foreach element $list {
 	    if {$element} { return 1}
-	} 
+	}
     	return 0
     }
-    
+
     proc booleanAs01 {list} {
 	set res {}
 	foreach element $list {
@@ -374,13 +378,13 @@ namespace eval loon::listfns {
 
     proc booleanNot {B} {
 	set n [llength $B]
-	
+
 	if {$n eq 1} {
 	    if {$B} {
 		return 0
 	    } else {
 		return 1
-	    }	
+	    }
 	} else {
 	    set x [list]
 	    foreach b $B {
@@ -392,8 +396,8 @@ namespace eval loon::listfns {
 	    }
 	    return $x
 	}
-    } 
-    
+    }
+
     # A \ B
     proc setDiff {A B} {
 	set out [list]
@@ -410,7 +414,7 @@ namespace eval loon::listfns {
 	set out {}
 	set A [lsort -unique $A]
 	set B [lsort -unique $B]
-	
+
 	if {[llength $A] > [llength $B]} {
 	    foreach b $B {
 		if {$b in $A} {
@@ -433,36 +437,36 @@ namespace eval loon::listfns {
 	set xmax $xmin
 	set ymin [lindex $xy 1]
 	set ymax $ymin
-	
+
 	foreach {x y} $xy {
 	    if {$x < $xmin} {
 		set xmin $x
 	    } elseif {$x > $xmax} {
 		set xmax $x
 	    }
-	    
+
 	    if {$y < $ymin} {
 		set ymin $y
 	    } elseif {$y > $ymax} {
 		set ymax $y
 	    }
 	}
-	
+
 	return [list $xmin $xmax $ymin $ymax]
     }
-    
-    
+
+
     proc drange {x} {
 	set tmp [::loon::listfns::MinMax $x]
 	return [expr {[lindex $tmp 1] - [lindex $tmp 0]}]
     }
-    
-    proc extractAndRemoveOption {listname name {default ""}} {	
-	set lst [uplevel 1 [list set $listname]]	
+
+    proc extractAndRemoveOption {listname name {default ""}} {
+	set lst [uplevel 1 [list set $listname]]
 	set i [lsearch -exact $lst $name]
-	
+
 	if {$i ne -1} {
-	    set ip1 [expr {$i + 1}] 
+	    set ip1 [expr {$i + 1}]
 	    set option [lindex $lst $ip1]
 	    uplevel 1 [list set $listname [lreplace $lst $i $ip1]]
 	} else {
@@ -478,14 +482,14 @@ namespace eval loon::listfns {
 	}
 	set p [llength $args]
 	set n [llength [lindex $args 0]]
-	
+
 	set out {}
 	for {set j 0} {$j < $n} {incr j} {
-	    for {set i 0} {$i < $p} {incr i} {    
-		lappend out [lindex [lindex $args $i] $j]  
-	    }      
+	    for {set i 0} {$i < $p} {incr i} {
+		lappend out [lindex [lindex $args $i] $j]
+	    }
 	}
-	return $out	
+	return $out
     }
 
     ## e.g ljoin {1 2 3} {a b c} > {1a 2b 3c}
@@ -496,8 +500,8 @@ namespace eval loon::listfns {
 	}
 	return $out
     }
-    
-    
+
+
     ## from R jitter function
     proc jitter {x {factor 1} {amount ""}} {
 	if {[llength $x] eq 0} {
@@ -506,7 +510,7 @@ namespace eval loon::listfns {
 	if {![isNumeric $x]} {
 	    error "x must be numeric"
 	}
-	
+
 	set z [drange $x]
 	if {$z eq 0} {
 	    set z [min $x]
@@ -516,12 +520,12 @@ namespace eval loon::listfns {
 	}
 	if {$amount eq ""} {
 	    set xx [lsort -unique [round $x [expr {3-floor(log10($z))}]]]
-	    set d {} 
+	    set d {}
 	    ## R diff() function
 	    foreach ixx0 [lreplace $xx end end] ixx1 [lreplace $xx 0 0] {
 		lappend d [expr {$ixx1 - $ixx0}]
 	    }
-	    
+
 	    if {[llength $d] ne 0} {
 		set d [min $d]
 	    } elseif {$xx != 0} {
@@ -529,25 +533,25 @@ namespace eval loon::listfns {
 	    } else {
 		set d [expr {$z / 10.0}]
 	    }
-	    
+
 	    set amount [expr {$factor/5.0*abs($d)}]
 
 	} elseif {$amount eq 0} {
 	    set amount [expr {$factor * $z/50.0}]
 	}
-	
+
 	set out {}
 	foreach e $x {
 	    lappend out [expr {$e + 2.0*rand()*$amount - $amount}]
 	}
 	return $out
     }
-    
+
     proc round {x {decimalplaces 0}} {
 	set out {}
-	
+
 	set f [expr {pow(10, $decimalplaces)}]
-	
+
 	foreach e $x {
 	    lappend out [expr {double(round($f*$e))/$f}]
 	}
@@ -559,19 +563,19 @@ namespace eval loon::listfns {
 	if {[llength $vec] ne 2} {
 	    error "vec needs to have 2 elements"
 	}
-	
+
 	set nvec [norm $vec]
-	
+
 	set v1 [lindex $nvec 0]
 	set v2 [lindex $nvec 1]
 
 	set out {}
 	foreach xe $x ye $y {
 	    lappend out [expr {$xe*$v1+$ye*$v2}]
-	} 
+	}
 	return $out
     }
-    
+
     proc norm {vec} {
 	set ssum 0
 	foreach x $vec {
@@ -584,7 +588,7 @@ namespace eval loon::listfns {
 	}
 	return $out
     }
-    
+
     proc dot {v1 v2} {
         if {[llength $v1] ne [llength $v1]} {
             error "v1 needs to have same dimension as v2"
@@ -595,7 +599,7 @@ namespace eval loon::listfns {
         }
         return $out
     }
-    
+
     proc transpose { matrix } {
         set transposed {}
         set i 0
@@ -609,7 +613,7 @@ namespace eval loon::listfns {
         }
         return $transposed
     }
-    
+
     proc matmul { m1 m2 } {
         set result {}
         set m2t [transpose $m2]
@@ -639,6 +643,6 @@ namespace eval loon::listfns {
 	return [split [string map [list $splitStr $mc] $str] $mc]
     }
 
-    
+
 }
 
